' BandWidthPlotII.bas for FilmStar DESIGN, MEASURE
' Copyright 1995-2010 FTG Software Associates
'
' ****************************************************
'    Warning: Save modified program with new name!!!
' ****************************************************
'
' Plots graph showing max, center, 50% and 1% bandwidth
' Based on BandWidth.bas
'
' To run this program as a macro, insert the following under Evaluate...Macro...Edit
' (adjusting if your winfilm directory is different)
'
'   Description   BandPass Filter
'   Command       basrun c:\Winfilm\Basic32\BandWidthPlotII.bas;
'
Option Explicit
DefInt I-N
DefSng A-H, O-Z

Sub Main
    Dim k, kErr As Boolean, b50, b01, tm, tm0, wc, wMin, wMax, gs$, wu$
    Busy True
    ' Calculate within range wMin, wMax as shown in FilmStar DESIGN, MEASURE screen
    ' This allows the spectral data set to be larger than the displayed axes when
    ' there are several peaks to be considered

    ' *****************************************
    '      Included for new DESIGN users
    '      Change or delete as required
    FileOpen "FnumDiabatic.faw"
    ' *****************************************
    GraphSetup

    ' NMEACGT:  N nm  M m  E cm  A ngs  C 1/cm  G GHz  T Thz
    Select Case WaveUnit
    Case "N"
        wu$ = " nm"
    Case "M"
        wu$ = " m"
    Case "A"
        wu$ = " ngs"
    Case "C"
        wu$ = " 1/cm"
    End Select

    ' *****************************************
    '      Change to Scan if using MEASURE
    Calculate
    ' *****************************************

    AxesRange wMin, wMax   ' get range from current graph axes
    BandMax wMin, wMax, tm, kErr
    tm0 = 100*tm           ' max value in %
    If Not kErr Then BandCtr wMin, wMax, wc, kErr
    If Not kErr Then BandWidth 50, wMin, wMax, b50, kErr    ' 50%
    If Not kErr Then BandWidth 1, wMin, wMax, b01, kErr      ' 1%
    If Not kErr Then
        PlotClose
        gs$ = "vline " & tStr(wc) & ",5,|b " & eFmt$(wc) & wu$ & ",9;0" & vbCrLf
        gs$ = gs$ & "hline " & tStr(tm0) & ",5,|l" & Replace(Format$(tm0, "0.00"),",","`") & "%,9;0" & vbCrLf

        tm = tm0/2      ' half width
        gs$ = gs$ & "graph " & tStr(wc-b50/2) & "," & tStr(tm) & ",43,,9;0" & vbCrLf
        gs$ = gs$ & "graph " & tStr(wc+b50/2) & "," & tStr(tm) & ",45,,9;1" & vbCrLf
        gs$ = gs$ & "graph " & tStr(wc) & "," & tStr(tm) & ",0," & "|c50% BW   "& eFmt$(b50) & wu$ & ",9;2" & vbCrLf

        tm = tm0/100    ' 1% width
        gs$ = gs$ & "graph " & tStr(wc - b01/2) & "," & tStr(tm) & ",43,,9;0" & vbCrLf
        gs$ = gs$ & "graph " & tStr(wc + b01/2) & "," & tStr(tm) & ",45,,9;1" & vbCrLf
        gs$ = gs$ & "graph " & tStr(wc) & "," & tStr(tm) & ",0," & "|C  1% BW    " & eFmt$(b01) & wu$ & ",9;2"

        PlotAnnotation = gs$
        PlotAnnotate True   ' must be before PlotActivate
        PlotActivate
        PlotNext
    Else
        Display "----Error----", "Bandwidth Calculation", 6000, 4000, "Arial", 32, 1
    End If
    Busy False
End Sub

Sub AxesRange(wMin, wMax) ' works in DESIGN and MEASURE
    Dim k, s$
    k = Macro("AxesCopy;")
    s$ = Clipboard$()
    k = InStr(s$, vbTab)
    wMin = Val(Mid$(s$, 1, k -1))
    s$ = Mid$(s$, k + 1)
    k = InStr(s$, vbTab)
    wMax = Val(Mid$(s$, 1, k -1))
End Sub

Function tStr(ByVal v!) As String
    Select Case WaveUnit
    Case "M"
        tStr = Trim$(Str(Round(v,6)))
    Case Else
        tStr = Trim$(Str(Round(v,3)))
    End Select
End Function

Function eFmt$(v)
    ' Formats for European decimal (replace "," by "`")
    ' "`" is then replaced by "," in the FSPlot Module
    Select Case WaveUnit
    Case "M"
        eFmt$ = Replace(Format$(v, "0.0000"),",","`")
    Case Else
        eFmt$ = Replace(Format$(v, "0.00"),",","`")
    End Select
End Function

Sub GraphSetup
    ' FSPlot graph setup code for FilmStar BASIC:
    PlotConfig 8481857, 1028, 0
    PlotSize 8685, 7635, 78
    PlotTitleFont = "Arial"
    PlotTitleSize = 120
    PlotLegendSize = 100
    PlotAxesFont = "Arial"
    PlotAxesLabelSize = 100
    PlotAxesNumberSize = 100
    PlotFontFixed = False
    PlotFontFixedSize = 1
    PlotAxesConfig = 0
    PlotEdgeSpace 50, -25, 50, 50
    PlotAxesSpace .15, .3, .3, 2
    PlotColors "255, 16711680, 52224, 16711935, 8421376, 32896, 0, 8421504, 128, 8388608, 32768, 8388736"
    PlotBitmapMode = False
End Sub
